@@ -2,7 +2,7 @@ use std::collections::HashMap;
 
 /// ### 定义存放到store缓存中的值的枚举类型
 /// 
-#[derive(Debug, serde::Serialize)]
+#[derive(Debug, Clone, serde::Serialize, serde::Deserialize)]
 #[serde(rename_all = "kebab-case")]
 pub enum Value {
     /// 字符串类型
